---
title: <span class="badge builder"></span> ResourceDimensionConfig
---
# <span class="badge builder"></span> ResourceDimensionConfig

## Constructor

```python
ResourceDimensionConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.ResourceDimensionConfig
```

### <span class="badge object-method"></span> field

fixed: T -- will be added by each element

```python
def field(field: str) -> typing.Self
```

### <span class="badge object-method"></span> fixed

```python
def fixed(fixed: str) -> typing.Self
```

### <span class="badge object-method"></span> mode

```python
def mode(mode: common.ResourceDimensionMode) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ResourceDimensionConfig](./object-ResourceDimensionConfig.md)
